==> certmanager-model-v1alpha2-5.7.0-sources.jar: io/fabric8/certmanager/api/model/v1alpha2/CertificateRequestStatus.java <==

package io.fabric8.certmanager.api.model.v1alpha2;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import io.fabric8.kubernetes.api.model.Container;
import io.fabric8.kubernetes.api.model.ContainerPort;
import io.fabric8.kubernetes.api.model.EnvVar;
import io.fabric8.kubernetes.api.model.KubernetesResource;
import io.fabric8.kubernetes.api.model.LabelSelector;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.model.Volume;
import io.fabric8.kubernetes.api.model.VolumeMount;
import io.sundr.builder.annotations.Buildable;
import io.sundr.builder.annotations.BuildableReference;
import lombok.EqualsAndHashCode;
import lombok.ToString;

@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonPropertyOrder({
    "ca",
    "certificate",
    "conditions",
    "failureTime"
})
@JsonDeserialize(using = com.fasterxml.jackson.databind.JsonDeserializer.None.class)
@ToString
@EqualsAndHashCode
@Buildable(editableEnabled = true, validationEnabled = false, generateBuilderPackage = false, builderPackage = "io.fabric8.kubernetes.api.builder", refs = {
    @BuildableReference(ObjectMeta.class),
    @BuildableReference(ObjectReference.class),
    @BuildableReference(LabelSelector.class),
    @BuildableReference(Container.class),
    @BuildableReference(EnvVar.class),
    @BuildableReference(ContainerPort.class),
    @BuildableReference(Volume.class),
    @BuildableReference(VolumeMount.class)
})
public class CertificateRequestStatus implements KubernetesResource
{

    @JsonProperty("ca")
    @JsonInclude(JsonInclude.Include.NON_EMPTY)
    private List<Integer> ca = new ArrayList<Integer>();
    @JsonProperty("certificate")
    @JsonInclude(JsonInclude.Include.NON_EMPTY)
    private List<Integer> certificate = new ArrayList<Integer>();
    @JsonProperty("conditions")
    @JsonInclude(JsonInclude.Include.NON_EMPTY)
    private List<CertificateRequestCondition> conditions = new ArrayList<CertificateRequestCondition>();
    @JsonProperty("failureTime")
    private String failureTime;
    @JsonIgnore
    private Map<String, Object> additionalProperties = new HashMap<String, Object>();

    /**
     * No args constructor for use in serialization
     * 
     */
    public CertificateRequestStatus() {
    }

    /**
     * 
     * @param certificate
     * @param failureTime
     * @param conditions
     * @param ca
     */
    public CertificateRequestStatus(List<Integer> ca, List<Integer> certificate, List<CertificateRequestCondition> conditions, String failureTime) {
        super();
        this.ca = ca;
        this.certificate = certificate;
        this.conditions = conditions;
        this.failureTime = failureTime;
    }

    @JsonProperty("ca")
    public List<Integer> getCa() {
        return ca;
    }

    @JsonProperty("ca")
    public void setCa(List<Integer> ca) {
        this.ca = ca;
    }

    @JsonProperty("certificate")
    public List<Integer> getCertificate() {
        return certificate;
    }

    @JsonProperty("certificate")
    public void setCertificate(List<Integer> certificate) {
        this.certificate = certificate;
    }

    @JsonProperty("conditions")
    public List<CertificateRequestCondition> getConditions() {
        return conditions;
    }

    @JsonProperty("conditions")
    public void setConditions(List<CertificateRequestCondition> conditions) {
        this.conditions = conditions;
    }

    @JsonProperty("failureTime")
    public String getFailureTime() {
        return failureTime;
    }

    @JsonProperty("failureTime")
    public void setFailureTime(String failureTime) {
        this.failureTime = failureTime;
    }

    @JsonAnyGetter
    public Map<String, Object> getAdditionalProperties() {
        return this.additionalProperties;
    }

    @JsonAnySetter
    public void setAdditionalProperty(String name, Object value) {
        this.additionalProperties.put(name, value);
    }

}

==> certmanager-model-v1alpha2-5.9.0-sources.jar: io/fabric8/certmanager/api/model/v1alpha2/CertificateRequestStatus.java <==

package io.fabric8.certmanager.api.model.v1alpha2;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import io.fabric8.kubernetes.api.model.Container;
import io.fabric8.kubernetes.api.model.ContainerPort;
import io.fabric8.kubernetes.api.model.EnvVar;
import io.fabric8.kubernetes.api.model.KubernetesResource;
import io.fabric8.kubernetes.api.model.LabelSelector;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.model.Volume;
import io.fabric8.kubernetes.api.model.VolumeMount;
import io.sundr.builder.annotations.Buildable;
import io.sundr.builder.annotations.BuildableReference;
import lombok.EqualsAndHashCode;
import lombok.ToString;

@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonPropertyOrder({
    "ca",
    "certificate",
    "conditions",
    "failureTime"
})
@JsonDeserialize(using = com.fasterxml.jackson.databind.JsonDeserializer.None.class)
@ToString
@EqualsAndHashCode
@Buildable(editableEnabled = false, validationEnabled = false, generateBuilderPackage = false, builderPackage = "io.fabric8.kubernetes.api.builder", refs = {
    @BuildableReference(ObjectMeta.class),
    @BuildableReference(ObjectReference.class),
    @BuildableReference(LabelSelector.class),
    @BuildableReference(Container.class),
    @BuildableReference(EnvVar.class),
    @BuildableReference(ContainerPort.class),
    @BuildableReference(Volume.class),
    @BuildableReference(VolumeMount.class)
})
public class CertificateRequestStatus implements KubernetesResource
{

    @JsonProperty("ca")
    @JsonInclude(JsonInclude.Include.NON_EMPTY)
    private List<Integer> ca = new ArrayList<Integer>();
    @JsonProperty("certificate")
    @JsonInclude(JsonInclude.Include.NON_EMPTY)
    private List<Integer> certificate = new ArrayList<Integer>();
    @JsonProperty("conditions")
    @JsonInclude(JsonInclude.Include.NON_EMPTY)
    private List<CertificateRequestCondition> conditions = new ArrayList<CertificateRequestCondition>();
    @JsonProperty("failureTime")
    private String failureTime;
    @JsonIgnore
    private Map<String, Object> additionalProperties = new HashMap<String, Object>();

    /**
     * No args constructor for use in serialization
     * 
     */
    public CertificateRequestStatus() {
    }

    /**
     * 
     * @param certificate
     * @param failureTime
     * @param conditions
     * @param ca
     */
    public CertificateRequestStatus(List<Integer> ca, List<Integer> certificate, List<CertificateRequestCondition> conditions, String failureTime) {
        super();
        this.ca = ca;
        this.certificate = certificate;
        this.conditions = conditions;
        this.failureTime = failureTime;
    }

    @JsonProperty("ca")
    public List<Integer> getCa() {
        return ca;
    }

    @JsonProperty("ca")
    public void setCa(List<Integer> ca) {
        this.ca = ca;
    }

    @JsonProperty("certificate")
    public List<Integer> getCertificate() {
        return certificate;
    }

    @JsonProperty("certificate")
    public void setCertificate(List<Integer> certificate) {
        this.certificate = certificate;
    }

    @JsonProperty("conditions")
    public List<CertificateRequestCondition> getConditions() {
        return conditions;
    }

    @JsonProperty("conditions")
    public void setConditions(List<CertificateRequestCondition> conditions) {
        this.conditions = conditions;
    }

    @JsonProperty("failureTime")
    public String getFailureTime() {
        return failureTime;
    }

    @JsonProperty("failureTime")
    public void setFailureTime(String failureTime) {
        this.failureTime = failureTime;
    }

    @JsonAnyGetter
    public Map<String, Object> getAdditionalProperties() {
        return this.additionalProperties;
    }

    @JsonAnySetter
    public void setAdditionalProperty(String name, Object value) {
        this.additionalProperties.put(name, value);
    }

}
